@@ -9,33 +9,14 @@ from s3.client import Client as S3Client
 
 def run_from_config(
         file_dir,
-        etl_name_no_version,
-        execution_date,
-        args_s3,
-        sql_credentials,
-        amocrm_secrets,
-        is_oauth2=True
+        **args_additional
 ):
     """
-    Read airflow task parameters (environment variables) to run sequence of tasks
-    :param is_oauth2:             ->type of authorization
-    :param file_dir:              ->path to file to read
-    :param etl_name_no_version:   ->etl_name_no_version to generate s3 path
-    :param execution_date:        ->execution_date to generate s3 path
-    :param args_s3:               ->s3 attributes
-    :param sql_credentials:       ->sql variable
-    :param amocrm_secrets:        ->
-    :return: Nothing
-    """
-    args_additional = {
-        "etl_name_no_version": etl_name_no_version,
-        "sql_credentials": sql_credentials,
-        "args_s3": args_s3,
-        "execution_date": execution_date,
-        "amocrm_secrets": amocrm_secrets,
-        "is_oauth2": is_oauth2
-    }
 
+    :param file_dir: file.json to run
+    :param args_additional: additional arguments to AmocrmRunner
+    :return:
+    """
     config_list = get_config_list(file_dir)
     for config_entity in config_list:
         extract_params, db_params_list = config_entity
@@ -207,11 +188,14 @@ class AmocrmRunner:
             "entity": self.entity,
             "table_name": self.table_name,
             "json_columns": self.json_columns,
+            "api_version": self.api_version
         }
         if db == "vertica":
             from amocrm.db.vertica_uploader import UploaderDB
         elif db == "ch":
             from amocrm.db.clickhouse_uploader import UploaderDB
+            if self.date_modified_from is not None:
+                args['full_copy'] = True
 
             args["table_to_optimize"] = self.table_to_optimize
 
